PageCacheEntry

Struct PageCacheEntry 

pub struct PageCacheEntry {
    paddr: PhysicalAddress,
    pin_count: AtomicUsize,
    is_dirty: AtomicUsize,
}
Entry in the page cache representing a single cached page

Fields

paddr: PhysicalAddress

Physical address of the cached page

pin_count: AtomicUsize

Pin count - number of active short-term accesses Pages with pin_count > 0 cannot be evicted

is_dirty: AtomicUsize

Dirty flag - true if page has been modified and needs writeback

Implementations

Source

impl PageCacheEntry

fn new(paddr: PhysicalAddress) -> Self

Create a new page cache entry

pub fn paddr(&self) -> PhysicalAddress

Get the physical address

fn pin(&self)

Increment pin count

fn unpin(&self)

Decrement pin count

fn pin_count(&self) -> usize

Get current pin count

fn mark_dirty(&self)

Mark page as dirty

fn is_dirty(&self) -> bool

Check if page is dirty