Struct PinnedPage
Source pub struct PinnedPage {
id: CacheId,
index: PageIndex,
paddr: PhysicalAddress,
}
RAII guard for a pinned page.
Unpins the page on Drop. Provides helpers to access the page and mark it dirty.
Physical address of the pinned page
Page index within the object
Executes the destructor for this type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.